#
# spec file for package arm-trusted-firmware
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global platform rk3399%{nil}

%if "%{platform}" == "a3700" || "%{platform}" == "imx8mq" || "%{platform}" == "sun50i_a64"
# Debug build not supported for UART boot on a3700
# Debug build is too big on imx8mq, see: https://developer.trustedfirmware.org/T626
# Debug build is too big on sun50i_a64 see: https://git.trustedfirmware.org/ci/tf-a-ci-scripts.git/commit/?id=3a78c106bb417a48572c46923c935e8193c4a7bf
%global debug_build 0
%else
%global debug_build 1
%endif

%bcond_without A3700_tools

%bcond_with atf_optee

%if %{with atf_optee}
%define use_optee 1
%if "%{platform}" == "" || "%{platform}" == "fvp" || "%{platform}" == "tegra186" || "%{platform}" == "tegra210" || "%{platform}" == "rk3328" || "%{platform}" == "rk3368" || "%{platform}" == "rk3399" || "%{platform}" == "rpi4"
# OP-TEE not available
%define use_optee 0
%endif
%if "%{platform}" == "a3700" || "%{platform}" == "a80x0_mcbin" || "%{platform}" == "imx8qm" || "%{platform}" == "imx8qx" || "%{platform}" == "imx8mq" || "%{platform}" == "imx8mm" || "%{platform}" == "sun50i_a64" || "%{platform}" == "sun50i_h6" || "%{platform}" == "sun50i_h616" || "%{platform}" == "zynqmp"
# TBD
%define use_optee 0
%endif
%else
%define use_optee 0
%endif

%if "%{platform}" == ""
Name:           arm-trusted-firmware
%else
Name:           arm-trusted-firmware-%{platform}
%endif
Version:        2.10.7
Release:        64.2
%define srcversion 2.10.7
%define mv_ddr_ver armada-atf-master
%define mv_bin_ver 10.0.1.0
%define a3700_utils_ver master
Summary:        Arm Trusted Firmware-A
License:        BSD-3-Clause
Group:          System/Boot
URL:            https://www.trustedfirmware.org/
Source:         https://github.com/TrustedFirmware-A/trusted-firmware-a/archive/refs/tags/lts-v%{srcversion}.tar.gz#/trusted-firmware-a-lts-v%{srcversion}.tar.gz
Source1:        mv-ddr-marvell-%{mv_ddr_ver}.tar.gz
Source2:        A3700-utils-marvell-%{a3700_utils_ver}.tar.gz
Source3:        binaries-marvell-%{mv_bin_ver}.tar.gz
Patch1:         atf-allow-non-git-dir.patch
Patch2:         rockchip-rk3399-Align-default-baudrate-with-u-boot.patch
Patch3:         Workaround-gcc-7-constant-assignment-error.patch
# Workaround for GCC12 bug - https://gcc.gnu.org/bugzilla/show_bug.cgi?id=105523
Patch100:       fix-mv-ddr-marvell-armada.patch
# Fix build with GCC12 - https://github.com/MarvellEmbeddedProcessors/mv-ddr-marvell/issues/37
Patch101:       fix-a3700_tool.patch
Patch150:       A3700_utils-drop-git.patch
BuildRequires:  fdupes
%if "%{platform}" != ""
#!BuildIgnore: gcc-PIE
%endif
%if "%{platform}" == "a3700"
BuildRequires:  arm-trusted-firmware-tools
BuildRequires:  cross-arm-none-newlib-devel
BuildRequires:  gcc-c++
BuildRequires:  libcryptopp-devel
%endif
%if "%{platform}" == "a3700" || "%{platform}" == "rk3399"
BuildRequires:  cross-arm-none-gcc%{gcc_version}
%endif
%if "%{platform}" == "a80x0_mcbin" && 0
BuildRequires:  edk2-Armada80x0McBin
%endif
%if "%{platform}" == "fvp"
BuildRequires:  dtc
BuildRequires:  edk2-ArmVExpress-FVP-AArch64
%endif
%if "%{platform}" == "hikey"
BuildRequires:  edk2-hikey
%endif
%if "%{platform}" == "hikey960"
BuildRequires:  edk2-hikey960
%endif
%if "%{platform}" == ""
BuildRequires:  gcc-c++
%endif
BuildRequires:  git
%if "%{platform}" == ""
BuildRequires:  libcryptopp-devel
%endif
BuildRequires:  libopenssl-devel
%if %{use_optee}
%if "%{platform}" == "qemu_sbsa"
BuildRequires:  optee-qemu-armv8a
%else
%if "%{platform}" == "a3700"
BuildRequires:  optee-armada3700
%else
%if "%{platform}" == "a80x0_mcbin"
BuildRequires:  optee-armada7k8k
%else
BuildRequires:  optee-%{platform}
%endif
%endif
%endif
%endif
%if "%{platform}" == "qemu"
BuildRequires:  qemu-uefi-aarch64
%endif
%if "%{platform}" == "rpi3" || "%{platform}" == "rpi4"
# For /boot/vc
BuildRequires:  raspberrypi-firmware
%endif
%if "%{platform}" == "a3700"
BuildRequires:  u-boot-mvebuespressobin-88f3720
%endif
%if "%{platform}" == "a80x0_mcbin" && 1
BuildRequires:  u-boot-mvebumcbin-88f8040
%endif
%if "%{platform}" == "hikey"
BuildRequires:  u-boot-hikey
%endif
%if "%{platform}" == "poplar"
BuildRequires:  u-boot-poplar
%endif
%if "%{platform}" == "rpi3"
BuildRequires:  u-boot-rpi3
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if "%{platform}" != ""
BuildArch:      noarch
ExclusiveArch:  aarch64
%endif

%if "%{platform}" == "rpi4"
Supplements:    modalias(of:N*T*Cbrcm%2Cbcm2711*C*)
%endif

%description
Trusted Firmware-A (TF-A) provides a reference implementation of secure world
software for Armv7-A and Armv8-A, including a Secure Monitor executing at
Exception Level 3 (EL3).

%if "%{platform}" == "poplar"
%package devel
Summary:        ARM Trusted Firmware -- %{platform} development files
Group:          System/Boot
Requires:       %{name} = %{version}

%description devel
ARM Trusted Firmware provides a reference implementation of
secure world software for ARMv8-A, including a Secure Monitor executing at
Exception Level 3 (EL3). It implements various ARM interface standards,
such as the Power State Coordination Interface (PSCI),
Trusted Board Boot Requirements (TBBR, ARM DEN0006C-1) and
SMC Calling Convention. As far as possible the code is designed for reuse
or porting to other ARMv8-A model and hardware platforms.

This sub-package contains development files.
%endif

%if "%{platform}" == ""
%package tools
Summary:        Tools for ARM Trusted Firmware-A
Group:          System/Boot

%description tools
Trusted Firmware-A (TF-A) provides a reference implementation of
secure world software for ARMv8-A, including a Secure Monitor executing at
Exception Level 3 (EL3). It implements various ARM interface standards,
such as the Power State Coordination Interface (PSCI),
Trusted Board Boot Requirements (TBBR, ARM DEN0006C-1) and
SMC Calling Convention. As far as possible the code is designed for reuse
or porting to other ARMv8-A model and hardware platforms.

This package contains fiptool.
%endif

%prep
%if "%{platform}" == "a3700" || "%{platform}" == "a80x0_mcbin"
%if "%{platform}" == "a3700"
%setup -q -a 1 -a 2 -n trusted-firmware-a-lts-v%{srcversion}
%else
%setup -q -a 1 -a 3 -n trusted-firmware-a-lts-v%{srcversion}
%endif
# git repo or branch.txt file are expected
echo "%{mv_ddr_ver}" > mv-ddr-marvell-%{mv_ddr_ver}/branch.txt
pushd mv-ddr-marvell-%{mv_ddr_ver}
%if %{suse_version} > 1550
# Workaround for GCC12 bug - https://gcc.gnu.org/bugzilla/show_bug.cgi?id=105523
%patch -P 100 -p1
%endif
%patch -P 101 -p1
popd
%else
%if "%{platform}" == ""
%setup -q -n trusted-firmware-a-lts-v%{srcversion} -a 2
%else
%setup -q -n trusted-firmware-a-lts-v%{srcversion}
%endif
%endif
%if "%{platform}" == "" || "%{platform}" == "a3700"
pushd A3700-utils-marvell-%{a3700_utils_ver}
# git repo or branch.txt file are expected
echo "%{a3700_utils_ver}" >  branch.txt
%if "%{platform}" != ""
install -D -m 0755 %{_bindir}/TBB wtptp/linux/tbb_linux
%endif
%patch -P 150 -p1
popd
%endif
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%if %{suse_version} <= 1500
# GCC7 does not support -mbranch-protection option
sed -i -e "s/TF_CFLAGS_aarch64	+=	-mbranch-protection=none//" plat/xilinx/zynqmp/platform.mk
%endif

%build
export TF_LDFLAGS=--no-warn-rwx-segments
export BUILD_MESSAGE_TIMESTAMP="\"$(date -d "$(head -n 2 %{_sourcedir}/arm-trusted-firmware.changes | tail -n 1 | cut -d- -f1 )" -u "+%%H:%%M:%%S, %%b %%e %%Y")\""
%if "%{platform}" == "a3700"
export CRYPTOPP_LIBDIR=%{_libdir}
export CRYPTOPP_INCDIR=%{_includedir}/cryptopp
%endif

%if "%{platform}" == ""
make %{?_smp_mflags} V=1 fiptool

%if %{with A3700_tools}
pushd A3700-utils-marvell-%{a3700_utils_ver}
make %{?_smp_mflags} -C wtptp/src/TBB_Linux -f TBB_linux.mak INCDIR=%{_includedir}/cryptopp LIBDIR=%{_libdir}
make %{?_smp_mflags} -C wtptp/src/Wtpdownloader_Linux -f makefile.mk
popd
%endif

%else
%if "%{platform}" == "a3700"
export CROSS_CM3=arm-none-eabi-
%define variants ebin_512M_spinor ebin_v3_1G_spinor ebin_v5_2G_spinor ebin_v7_1G_spinor ebin_v7_2G_spinor ebin_512M_sata ebin_v3_1G_sata ebin_v5_2G_sata ebin_v7_1G_sata ebin_v7_2G_sata
for variant in %{variants}; do
  partnum=0
  case "${variant}" in
  ebin_*)
    clockspreset=CPU_1000_DDR_800
    ;;
  esac
  case "${variant}" in
  ebin_512M_*)
    ddr_topology=0
    ;;
  ebin_v3_1G_*)
    ddr_topology=2
    ;;
  ebin_v5_2G_*)
    ddr_topology=7
    ;;
  ebin_v7_1G_*)
    ddr_topology=5
    ;;
  ebin_v7_2G_*)
    ddr_topology=6
    ;;
  esac
  case "${variant}" in
  *_emmc)    bootdev=EMMCNORM ;;
  *_sata)    bootdev=SATA ;;
  *_spinand) bootdev=SPINAND ;;
  *_spinor)  bootdev=SPINOR ;;
  esac
  make distclean
%endif
%if "%{platform}" == "poplar"
for dram_size in one_gig two_gig; do
%endif
%if 0%{suse_version} > 1550
# Workaround for GCC12 bug - https://gcc.gnu.org/bugzilla/show_bug.cgi?id=105523
export TF_CFLAGS="$TF_CFLAGS --param=min-pagesize=0"
export CFLAGS="$CFLAGS --param=min-pagesize=0"
# Workaround for binutils 2.39 https://developer.trustedfirmware.org/T996
export LDFLAGS="$LDFLAGS --no-warn-rwx-segment"
%endif
make \
%if "%{platform}" != "a3700" && "%{platform}" != "a80x0_mcbin"
     %{?_smp_mflags} \
%endif
     V=1 DISABLE_PEDANTIC=1 DEBUG=%{debug_build} \
%if "%{platform}" == "tegra186" || "%{platform}" == "tegra210"
%if "%{platform}" == "tegra186"
%define target_soc t186
%endif
%if "%{platform}" == "tegra210"
%define target_soc t210
%endif
     PLAT=tegra TARGET_SOC=%{target_soc} \
%else
     PLAT=%{platform} \
%endif
%if %{use_optee}
     SPD=opteed \
     BL32=/boot/tee-header_v2.bin \
     BL32_EXTRA1=/boot/tee-pager_v2.bin \
     BL32_EXTRA2=/boot/tee-pageable_v2.bin \
%endif
%if "%{platform}" == "a3700" || "%{platform}" == "a80x0_mcbin"
     LOG_LEVEL=30 \
     MV_DDR_PATH=$(pwd)/mv-ddr-marvell-%{mv_ddr_ver} \
%if "%{platform}" == "a3700"
     WTP=$(pwd)/A3700-utils-marvell-%{a3700_utils_ver} \
     CLOCKSPRESET=${clockspreset} DDR_TOPOLOGY=${ddr_topology} \
     USE_COHERENT_MEM=0 \
%if %{use_optee}
     LLC_ENABLE=1 LLC_SRAM=1 \
%endif
     BOOTDEV=${bootdev} PARTNUM=${partnum} \
     MARVELL_SECURE_BOOT=0 \
%endif
%if "%{platform}" == "a80x0_mcbin"
     SCP_BL2=$(pwd)/binaries-marvell-%{mv_bin_ver}/mrvl_scp_bl2.img \
%endif
%if "%{platform}" == "a80x0_mcbin" && 0
     BL33=/boot/ARMADA_EFI.fd \
%else
     BL33=/boot/u-boot.bin \
%endif
%if "%{platform}" == "a3700" || "%{platform}" == "a80x0_mcbin"
     mrvl_flash \
%if "%{platform}" == "a3700"
     mrvl_uart  \
%endif
%endif
     all fip
%if "%{platform}" == "a3700"
mv build build.${variant}
done
%endif
%else
%if "%{platform}" == "fvp"
     BL33=/boot/FVP_AARCH64_EFI.fd \
     all fip
%else
%if "%{platform}" == "hikey"
     SCP_BL2=/boot/mcuimage.bin \
     BL33=/boot/u-boot.bin \
     all fip
%else
%if "%{platform}" == "hikey960"
     SCP_BL2=/boot/lpm3.img \
     BL33=/boot/BL33_AP_UEFI.fd \
     all fip
%else
%if "%{platform}" == "poplar"
     BL33=/boot/u-boot.bin \
     POPLAR_DRAM_SIZE=${dram_size} \
     all fip
mv build build.${dram_size}
make %{?_smp_mflags} V=1 DISABLE_PEDANTIC=1 DEBUG=%{debug_build} \
     PLAT=poplar POPLAR_RECOVERY=1 \
     BL33=/boot/u-boot.bin \
     POPLAR_DRAM_SIZE=${dram_size} \
     all fip
mv build build.${dram_size}.recovery
done
%else
%if "%{platform}" == "rpi3"
     BL33=/boot/vc/u-boot.bin \
     RPI3_PRELOADED_DTB_BASE=0x01000000 \
     RPI3_DIRECT_LINUX_BOOT=1 \
     RPI3_RUNTIME_UART=1 \
     all
%else
%if "%{platform}" == "qemu"
     BL33=%{_datadir}/qemu/qemu-uefi-aarch64.bin \
     all fip
%else
%if "%{platform}" == "qemu_sbsa"
     all fip
%else
     all
%endif
%endif
%endif
%endif
%endif
%endif
%endif
%endif
%endif

%install
%if "%{platform}" == ""
mkdir -p %{buildroot}%{_bindir}
install -m 755 tools/fiptool/fiptool %{buildroot}%{_bindir}/fiptool

%if %{with A3700_tools}
pushd A3700-utils-marvell-%{a3700_utils_ver}
# No need to have a _linux suffix on Linux
install -D -m 0755 wtptp/src/TBB_Linux/release/TBB_linux %{buildroot}%{_bindir}/TBB
install -D -m 0755 wtptp/src/Wtpdownloader_Linux/WtpDownload_linux %{buildroot}%{_bindir}/WtpDownload
popd
%endif
%else

export NO_BRP_STRIP_DEBUG=true
export NO_DEBUGINFO_STRIP_DEBUG=true

mkdir -p %{buildroot}%{_datadir}/%{name}

%if 0%{?debug_build}
%global dir debug
%else
%global dir release
%endif
%define outdir build/%{platform}/%{dir}
%if "%{platform}" == "tegra186" || "%{platform}" == "tegra210"
%define outdir build/tegra/%{target_soc}/%{dir}
%endif
%if "%{platform}" == "a3700"
for v in %{variants}; do
  outdir=build.${v}/%{platform}/%{dir}
  destdir=%{buildroot}%{_datadir}/%{name}/${v}
  install -D -m 0644 ${outdir}/bl1.bin ${destdir}/bl1.bin
  install -D -m 0644 ${outdir}/bl2.bin ${destdir}/bl2.bin
  install -D -m 0644 ${outdir}/bl31.bin ${destdir}/bl31.bin
  install -D -m 0644 ${outdir}/fip.bin ${destdir}/fip.bin
  install -D -m 0644 ${outdir}/flash-image.bin ${destdir}/flash-image.bin
  install -D -m 0644 ${outdir}/uart-images/TIM_ATF.bin ${destdir}/uart/TIM_ATF.bin
  install -D -m 0644 ${outdir}/uart-images/boot-image_h.bin ${destdir}/uart/boot-image_h.bin
  install -D -m 0644 ${outdir}/uart-images/wtmi_h.bin ${destdir}/uart/wtmi_h.bin
done
%else
%if "%{platform}" == "poplar"
for v in one_gig two_gig one_gig.recovery two_gig.recovery; do
  outdir=build.${v}/%{platform}/%{dir}
  destdir=%{buildroot}%{_datadir}/%{name}/${v}
  install -D -m 0644 ${outdir}/bl1.bin ${destdir}/bl1.bin
  install -D -m 0644 ${outdir}/fip.bin ${destdir}/fip.bin
done
mkdir -p %{buildroot}%{_includedir}/%{name}
install -D -m 0644 plat/hisilicon/poplar/include/poplar_layout.h %{buildroot}%{_includedir}/%{name}/
%else

# u-boot for rockchip requires bl31.elf file
%if "%{platform}" == "rk3328" || "%{platform}" == "rk3368" || "%{platform}" == "rk3399" || "%{platform}" == "zynqmp"
install -D -m 0644 %{outdir}/bl31/bl31.elf %{buildroot}%{_datadir}/%{name}/bl31.elf
%else
install -D -m 0644 %{outdir}/bl31.bin %{buildroot}%{_datadir}/%{name}/bl31.bin
%endif

%if "%{platform}" == "a80x0_mcbin" || "%{platform}" == "fvp" || "%{platform}" == "hikey" || "%{platform}" == "hikey960" || "%{platform}" == "qemu" || "%{platform}" == "qemu_sbsa" || "%{platform}" == "rpi3"
install -D -m 0644 %{outdir}/bl1.bin %{buildroot}%{_datadir}/%{name}/bl1.bin
install -D -m 0644 %{outdir}/fip.bin %{buildroot}%{_datadir}/%{name}/fip.bin
%endif
%if "%{platform}" == "a80x0_mcbin" || "%{platform}" == "hikey" || "%{platform}" == "hikey960" || "%{platform}" == "rpi3"
install -D -m 0644 %{outdir}/bl2.bin %{buildroot}%{_datadir}/%{name}/bl2.bin
%endif
%if "%{platform}" == "rpi3"
install -D -m 0644 %{outdir}/armstub8.bin %{buildroot}/boot/vc/armstub8.bin
%endif
%if "%{platform}" == "rpi4"
install -D -m 0644 %{outdir}/bl31.bin %{buildroot}/boot/vc/armstub8-rpi4.bin
%endif
%if "%{platform}" == "a80x0_mcbin"
install -D -m 0644 %{outdir}/ble.bin %{buildroot}%{_datadir}/%{name}/ble.bin
install -D -m 0644 %{outdir}/flash-image.bin %{buildroot}%{_datadir}/%{name}/flash-image.bin
%endif

%endif
%endif

%endif

%fdupes %{buildroot}%{_prefix}

%if "%{platform}" == "rpi4"
%post
if mountpoint -q /boot/efi; then
  if ! [[ "$(readlink -f /boot/efi)" -ef "$(readlink -f /boot/vc)" ]]; then
    cp /boot/vc/armstub8* /boot/efi/
  fi
fi
%endif

%files
%defattr(-,root,root)
%license license.rst
%doc docs/about/acknowledgements.rst docs/process/contributing.rst docs/about/maintainers.rst readme.rst dco.txt
%if "%{platform}" != ""
%{_datadir}/%{name}
%endif
%if "%{platform}" == "rpi3" || "%{platform}" == "rpi4"
/boot/vc/armstub8*
%endif

%if "%{platform}" == ""
%files tools
%defattr(-,root,root)
%{_bindir}/fiptool
%if %{with A3700_tools}
%{_bindir}/TBB
%{_bindir}/WtpDownload
%endif
%endif

%if "%{platform}" == "poplar"
%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%endif

%changelog
* Wed Oct 16 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2.10.7:
  * Changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/+/refs/tags/lts-v2.10.7/docs/change-log.md
- Skipped 2.10.6:
  * Changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/+/refs/tags/lts-v2.10.6/docs/change-log.md
- Skipped 2.10.5:
  * Changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/+/refs/tags/lts-v2.10.5/docs/change-log.md
- Skipped 2.10.4:
  * Changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/+/refs/tags/lts-v2.10.4/docs/change-log.md
- Skipped 2.10.3:
  * Changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/+/refs/tags/lts-v2.10.3/docs/change-log.md
- Skipped 2.10.2:
  * Changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/+/refs/tags/lts-v2.10.2/docs/change-log.md
- Skipped 2.10.1:
  * Changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/+/refs/tags/lts-v2.10.1/docs/change-log.md
* Wed May 15 2024 Ivan Ivanov <ivan.ivanov@suse.com>
- Don't use TF-A on RPi3 by default, just keep it around for testing.
  Fixes bsc#1207204.
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Feb 12 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable imx8mq is it fails to build due to size constraints
* Thu Nov 23 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2.10.0:
  * Changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/commit/docs/change-log.md?id=9873580997c7f5ec60535bd45367d0c7d3cc2784
* Mon Sep 18 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2.9.0:
  * Changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/commit/docs/change-log.md?id=b78ad00e580596c4f0b5dfc41efbf5f5877cbdb9
* Mon Sep 18 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2.8.8:
  - **Libraries**
  - **CPU Support**
  - fix(cpus): workaround for Neoverse V2 erratum 2801372 ([ec3fafa](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/ec3fafa24307686b957de0899ba30bfbb5a70380))
- Skipped 2.8.7:
  - **Build System**
  - fix(build): allow warnings when using lld ([37bee49](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/37bee4983192451a00ed9dd5987e8e856fb09714))
  - build(makefile): add helper to detect linker options ([8782b88](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/8782b8849147aef0e0f8dcf54ec3f2d980acbf50))
  - feat(build): add support for new binutils versions ([1fdc979](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/1fdc9797f32c711c35a8a61a591607c8fa8a5468))
  - **Services**
  - **Errata ABI**
  - feat(errata_abi): errata management firmware interface ([bb9d6fa](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/bb9d6faa41ee9d60fdd310f446870b1dbcc41b03))
  - refactor(errata_abi): factor in non-arm interconnect ([4a001ff](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/4a001ffb68e0a8f306ca84a6c1c3142dff728aa2))
  - fix(cpus): workaround platforms non-arm interconnect ([f718c87](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/f718c8723aca40164340c416a0e9d96a37719fe5))
  - docs(errata_abi): document the errata abi changes ([66dab5c](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/66dab5c69420fc728a74d10a83f0abc0e4c4f756))
  - **Platforms**
  - **FVP**
  - feat(fvp): enable errata management interface ([b8bb1e3](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/b8bb1e347e5486583edda32e47af53a43165a3aa))
* Mon Apr 24 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2.8.6:
  - **Arm**
  - **GIC**
  - **GICv3**
  - fix(gicv3): workaround for NVIDIA erratum T241-FABRIC-4 ([2e48284](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/2e48284c8b5a4cf28779a30fd60d99650928865e))
  - **Bootloader Images**
  - **BL32**
  - **TSP**
  - fix(tsp): use verbose for power logs ([6cc8ca9](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/6cc8ca93a905cfdc791ab7a7d2b8d6c366b5705e))
- Skipped 2.8.5:
  - **Libraries**
  - **CPU Support**
  - refactor(cpus): shorten errata flag defines ([e31060c](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/e31060c472cd53ce5a21a5ce19cd663a3fd79ec3))
  - fix(cpus): workaround for Cortex-A78C erratum 1827430 ([14bb756](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/14bb7567d5e9805e5287651eeec5aa95cae40432))
  - fix(cpus): workaround for Cortex-A78C erratum 1827440 ([330095f](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/330095fa4a2695bac85fd12e0017090d9ebb633f))
- Skipped 2.8.4:
  - **Libraries**
  - **CPU Support**
  - fix(cpus): workaround for Neoverse V1 errata 2743233 ([08a0f6a](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/08a0f6acaa327b0de868a2fdff9fcdf5880de9db))
- Skipped 2.8.3:
  - **Libraries**
  - **CPU Support**
  - fix(cpus): workaround for Cortex-A78 erratum 2742426 ([a307605](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/a30760567eacce2b384ba072050eae4a422a5e9f))
  - fix(cpus): workaround for Cortex-A78C erratum 2779484 ([48f38bc](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/48f38bcb0465719a502d98bc04efe69553b3cb22))
  - **Dependencies**
  - **Compiler runtime libraries**
  - fix(deps): add missing aeabi_memset.S ([0aae8a3](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/0aae8a34b3ca8ed0885166cb5bf6af67bc91c5fa))
- Skipped 2.8.2:
  - **Platforms**
  - **Xilinx**
  - **ZynqMP**
  - fix(zynqmp): enable A53 workaround(errata 1530924) ([3c5ba11ca] (https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/3c5ba11ca800e41e36ea97b696cd3ce9c64d5412)))
- Skipped 2.8.1:
  - **Libraries**
  - **el3_runtime**
  - Revert "fix(el3_runtime): allow SErrors when executing in EL3" ([51120a499](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/51120a499ee7682ce659e613e197597e9376aae7))
- Skipped 2.8.0:
  - **Libraries**
  - **C Standard Library**
  - fix(libc): properly define SCHAR_MIN ([33d7e301f](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/33d7e301f74059b12b606cfc54afd48a9ad26b4a))
  - **CPU Support**
  - fix(cpus): workaround for Cortex-A510 erratum 2684597 ([a40d9559b](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/a40d9559b2f104923dc01c74dcdd4ac06b85adef))
  - fix(cpus): workaround for Cortex-A78C erratum 2772121 ([b33ea1e3e](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/b33ea1e3e91430d03d4328f1c7c094af7622ff2d))
  - fix(cpus): workaround for Neoverse V1 errata 2779461 ([c06124dad](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/c06124dadc10a4cdc63772483921810dbc3f4b95))
  - fix(cpus): workaround for Cortex-A78 erratum 2779479 ([5a25a70fb](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/5a25a70fb67f56be5f3ebed3d4234bb3b8120181))
  - fix(cpus): workaround for Cortex-X2 erratum 2282622 ([209b8ccd7](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/209b8ccd772d3b94b30b731bd85da1c3ecd0ecdb))
  - fix(cpus): workaround for Cortex-A710 erratum 2282622 ([a9f7a50d3](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/a9f7a50d30598d2bd7f3d048930e54c520adc69f))
  - fix(cpus): workaround for Neoverse V1 erratum 2743093 ([b7f723e55](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/b7f723e55f52f693e6517120bd016d56f0cdb80c))
  - fix(cpus): workaround for Cortex-A78 erratum 2772019 ([3a8011088](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/3a80110887ed752b0c6e5b4f0d59bd6d40f4bb24))
  - fix(cpus): workaround for Neoverse N2 erratum 2743089 ([b0b654f90](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/b0b654f908df85133e9d8cbbe252cf7f48dd883c))
  - fix(cpus): workaround for Cortex-X2 erratum 2768515 ([262bb3a22](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/262bb3a223bed377603ac756fef8d685fad016ef))
  - fix(cpus): workaround for Cortex-A710 erratum 2768515 ([c90daab3f](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/c90daab3f0029867f7d1b419dcb72961bdfaea9d))
  - fix(cpus): workaround for Cortex-X3 erratum 2615812 ([bcdd5152d](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/bcdd5152dc6c0496d25e936f3af4416dab1d32bc))
  - **el3_runtime**
  - fix(el3_runtime): allow SErrors when executing in EL3 ([327f4bb0c](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/327f4bb0cf2035ee46f0753429a43fd4c97a5d98))
  - fix(el3_runtime): restore SPSR/ELR/SCR after esb ([f06ba4a21](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/f06ba4a2137000e87f1ec77eef054d3ac1706d84))
  - **Miscellaneous**
  - **Debug**
  - fix(console): fix crash on spin_unlock with cache disabled ([cede543e2](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/cede543e29d7110adfd99427f35858e6a81cb596))
  - **Platforms**
  - **Arm**
  - **CSS**
  - fix(plat/css): fix invalid redistributor poweroff ([1432d4b86](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/1432d4b86ea11160d211470a15cdcdc1e36bb0fb))
  - **ST**
  - fix(st): include utils.h to solve compilation error ([06d5116f2](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/06d5116f29bcffef89ae3190bb4df3043cb91cf8))
  - **Intel**
  - fix(intel): fix fcs_client crashed when increased param size ([2b2eaf1d9](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/2b2eaf1d96255f5e56cf8469e98ee77631b0bcda))
  - **Layerscape**
  - fix(layerscape): unlock write access SMMU_CBn_ACTLR ([40b90a9c4](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/40b90a9c4ce8a7f131ea65edb549d8f0160a5999))
  - fix(layerscape): fix errata a008850 ([61cc890d7](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/61cc890d715e6d388ed15ba9cb1a5a8c66ded6c3))
  - **LX2**
  - feat(lx2): enable OCRAM ECC ([1c65e8798](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/1c65e8798b5be2a2ac7f3aaa410e02f7fc4b29ad))
  - feat(lx2): support more variants ([fa8a6d76f](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/fa8a6d76ffe03647676f12740fce5a2ed3735616))
  - fix(lx2): init global data before using it ([fd857216e](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/fd857216e5e7bec268579f4999b9c23dd7c1cfac))
  - **NXP**
  - fix(nxp-drivers): fix tzc380 memory regions config ([4b654f4b4](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/4b654f4b47267469426a3f77ad0981a1063ebf24))
  - fix(nxp-ddr): apply Max CDD values for warm boot ([1414e0add](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/1414e0adda7fdfa4405412c6328d52371e1e376a))
  - fix(nxp-ddr): use CDDWW for write to read delay ([8047151ab](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/8047151ab249c9f900132486c17d5bdf39d7ca51))
  - **ls1046a**
  - fix(ls1046a): 4 keys secureboot failure resolved ([ff8694041](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/ff8694041010045e3fcafe57aed0fbbe236d2cf5))
  - **Security**
  - docs(security): security advisory for CVE-2022-47630 ([084d29c26](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/084d29c2654f0717129aac116adb644df9a8387c))
  - fix(auth): properly validate X.509 extensions ([a89b1f193](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/a89b1f19303add7971828546f922bb9f889dae87))
  - fix(auth): avoid out-of-bounds read in auth_nvctr() ([187e79427](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/187e79427dd09ae4b47128aa17975dc1310453bc))
  - fix(auth): require at least one extension to be present ([379183edc](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/379183edc4d34e513678f652703b890c1db95d3b))
  - fix(auth): forbid junk after extensions ([609437cbf](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/609437cbf591d77050d4a4e2de4e0c322d71706e))
  - **Tools**
  - fix(sptool): add dependency to SP image ([9e01aedd4](https://review.trustedfirmware.org/plugins/gitiles/TF-A/trusted-firmware-a/+/9e01aedd4359311169f4e472240314db8494d251))
* Mon Apr  3 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add fvp platform
* Thu Jan 12 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable debug build on sun50i_a64 as it is too big
* Tue Jan 10 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to version 2.8:
  * changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/tree/docs/change-log.md
* Tue Jan 10 2023 Oscar Curero <oscar@naiandei.net>
- Add sun50i_h616 flavor for OrangePi Zero2
* Mon Nov 21 2022 Michal Suchanek <msuchanek@suse.com>
- Add --no-warn-rwx-segment always, the problem is not specific to Tumbleweed.
* Tue Aug 30 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add --no-warn-rwx-segment to LDFLAGS on Tumbleweed, as a
  workaround for binutils 2.39
  See https://developer.trustedfirmware.org/T996
* Mon Aug 29 2022 Michal Suchanek <msuchanek@suse.com>
- Workaround for gcc 7 constant assigment error (boo#1202477).
  + Workaround-gcc-7-constant-assignment-error.patch
* Wed Aug 17 2022 Michal Suchanek <msuchanek@suse.com>
- Do not disable build on Leap
- Fix build on Tumbleweed
* Wed Jul 13 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build of zynqmp with gcc7 (Leap 15.4)
* Fri Jul  8 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to version 2.7:
  * changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/tree/docs/change-log.md
- Drop usptream patches:
  0001-docs-security-security-advisory-for-CVE-2022-23960.patch
  0002-fix-security-workaround-for-CVE-2022-23960.patch
  0003-refactor-el3-runtime-change-Cortex-A76-implementatio.patch
  0004-fix-security-loop-workaround-for-CVE-2022-23960-for-.patch
  0005-fix-security-workaround-for-CVE-2022-23960-for-Corte.patch
  0006-fix-security-SMCCC_ARCH_WORKAROUND_3-mitigations-for.patch
* Fri Jul  1 2022 Michal Suchanek <msuchanek@suse.com>
- rockchip: rk3399: Align default baudrate with u-boot (boo#1201096).
  * rockchip-rk3399-Align-default-baudrate-with-u-boot.patch
* Thu May 19 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add "--param=min-pagesize=0" to CFLAGS as a workaround for
  GCC12 bug: https://gcc.gnu.org/bugzilla/show_bug.cgi?id=105523
- Add a patch to add "--param=min-pagesize=0" for
  mv-ddr-marvell-armada since it does not use CFLAGS:
  * fix-mv-ddr-marvell-armada.patch
- Fix bug on A3700 flavor found by GCC12:
  * fix-a3700_tool.patch
* Fri Mar 18 2022 Ivan Ivanov <ivan.ivanov@suse.com>
- Backport fallowing patches mitigating CVE-2022-23960 [1] and [2].
  0001-docs-security-security-advisory-for-CVE-2022-23960.patch
  0002-fix-security-workaround-for-CVE-2022-23960.patch
  0003-refactor-el3-runtime-change-Cortex-A76-implementatio.patch
  0004-fix-security-loop-workaround-for-CVE-2022-23960-for-.patch
  0005-fix-security-workaround-for-CVE-2022-23960-for-Corte.patch
  0006-fix-security-SMCCC_ARCH_WORKAROUND_3-mitigations-for.patch
  Fixes bsc#1196657
  [1] https://trustedfirmware-a.readthedocs.io/en/latest/security_advisories/security-advisory-tfv-9.html
  [2] https://review.trustedfirmware.org/q/topic:"spectre_bhb"
* Tue Feb  8 2022 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update A3700-utils-marvell version:
  Fix build SATA bootloader for A3700 boards
  Drop fix-A3700-gcc11.patch: upstreamed
  Enable %%fdupes which is particularly useful for a3700 flavour
* Wed Feb  2 2022 Stefan Weiberg <sweiberg@suse.com>
- ExclusiveArch got overwritten, using else branches instead as
  SLE 15 SP4 continued to build excluded flavours
  (related to bsc#1193779 and bsc#1195129)
* Mon Jan 31 2022 Stefan Weiberg <sweiberg@suse.com>
- Fixing the if statement to disable some targets on SLE 15 SP4, as
  the prior change resulted in the packages being built on other
  architectures than aarch64 on SLE 15 SP4
  (related to bsc#1193779 and bsc#1195129)
* Fri Jan 28 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable some targets on SLE15-SP4 because of missing deps in SLE:
  a3700, hikey, hikey960, imx8qm, imx8qx, rk3399
  Fixes bsc#1193779 and bsc#1195129
* Fri Jan 14 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add qemu_sbsa flavor
* Thu Jan  6 2022 Ivan Ivanov <ivan.ivanov@suse.com>
- Auto install on RPi4
* Fri Dec 10 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to version 2.6:
  * changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/tree/docs/change-log.md
- Update mv-ddr-marvell-armada-atf-master to latest version
- Drop upstreamed patch:
  * atf-2411053.diff
- Add patch to allow to use non-git checkouts:
  * atf-allow-non-git-dir.patch
* Tue Jul  6 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update mv-ddr-marvell to use master branch as upstream recommends
  This fixes build of a80x0_mcbin
- Update A3700-utils-marvell to use master branch as upstream recommends
- Re-enable A3700 tools with patch:
  * fix-A3700-gcc11.patch
- And refresh patch:
  * A3700_utils-drop-git.patch
* Thu Jun 10 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable A3700 tools until fixed upstream:
  https://github.com/MarvellEmbeddedProcessors/A3700-utils-marvell/issues/22
* Thu Jun  3 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix rk3399 build:
  * atf-2411053.diff
* Thu May 20 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to version 2.5:
  * changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/tree/docs/change-log.rst#version-25
* Fri Dec 11 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to version 2.4:
  * changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/tree/docs/change-log.rst#n7
- Replace mv-ddr-marvell-armada-atf-mainline.tar.gz with
  mv-ddr-marvell-mv-ddr-devel.tar.gz to match the upstream requirements
- Drop upstream patch:
  * mv-ddr.diff
* Sat Oct 17 2020 Andreas Färber <afaerber@suse.de>
- Fix BUILD_MESSAGE_TIMESTAMP (don't try parsing deleted .changes)
- Clean up rpi4 build
- Drop comments to avoid RPM errors about %%else and %%endif end of line
- Update mv-ddr-marvell from mv_ddr-atf-mainline branch to mv-ddr-devel 14.0.0
  * Add mv-ddr.diff (from d:A:F:Contrib:MacchiatoBin) to fix a warning treated as error
  * Add a _service to clarify its origin and facilitate future updates
- Update A3700-utils-marvell from armada-18.12 to armada-18.12-fixed branch
  * Drop A3700_utils-TBB-Split-INCDIR-from-LIBDIR.patch (merged)
  * Drop A3700_utils-TBB-Fix-building-for-Crypto-6.0-and-later.patch (merged)
  * Actually apply A3700_utils-drop-git.patch (output cleanup)
- Build and package A3700 utils as part of -tools (non-noarch, ensure PIE)
- Build the tools for all architectures again
- Add binaries-marvell from binaries-marvell-armada-SDK10.0.1.0 branch
- Add a80x0_mcbin and extend a3700 to build and package all needed files
  * Suppress OP-TEE for now, as it fails to initialize
* Fri Oct 16 2020 Andreas Färber <afaerber@suse.de>
- Build fixes for a3700 and a80x0_mcbin
* Thu Jul  2 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Add rpi4
* Thu Apr 23 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable debug on imx8mq to fix build
* Thu Apr 23 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2.3:
  * Add support for Armv8.4-SecEL2 extension through the SPCI defined SPMD/SPMC components.
  * Build option to support EL2 context save and restore in the secure world (CTX_INCLUDE_EL2_REGS).
  * Add support for SMCCC v1.2 (introducing the new SMCCC_ARCH_SOC_ID SMC).
    Note that the support is compliant, but the SVE registers save/restore will be done as part of future S-EL2/SPM development.
  * Enhanced BL2 bootloader flow to load secure partitions based on firmware configuration data (fconf).
  * Changes necessary to support SEPARATE_NOBITS_REGION feature
  * TSP and BL2_AT_EL3: Add Position Independent Execution PIE support
  * Enable MTE support
  * Enable Link Time Optimization in GCC
  * Add CPU support:
  - cortex-a57: Enable higher performance non-cacheable load forwarding
  - Hercules: Workaround for Errata 1688305
  - Klein: Support added for Klein CPU
  - Matterhorn: Support added for Matterhorn CPU
  * Full changelog:  https://trustedfirmware-a.readthedocs.io/en/latest/change-log.html#version-2-3
* Sat Feb  1 2020 Matwey Kornilov <matwey.kornilov@gmail.com>
- Initial implementation for Marvel A3700 platform
* Thu Oct 24 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Switch to _multibuild system
- Update to 2.2:
  * Enable Pointer Authentication (PAuth) support for Secure World
  - Adds support for ARMv8.3-PAuth in BL1 SMC calls and BL2U
    image for firmware updates.
  * Enable Memory Tagging Extension (MTE) support in both secure
    and non-secure worlds
  - Adds support for the new Memory Tagging Extension arriving
    in ARMv8.5. MTE support is now enabled by default on
    systems that support it at EL0.
  - To enable it at ELx for both the non-secure and the secure
    world, the compiler flag CTX_INCLUDE_MTE_REGS includes
    register saving and restoring when necessary in order to
    prevent information leakage between the worlds.
  * Add support for Branch Target Identification (BTI)
  * Full changelog: https://trustedfirmware-a.readthedocs.io/en/latest/change-log.html#version-2-2
- Drop upstreamed patches:
  * arm-trusted-firmware_hikey960_race.patch
  * arm-trusted-firmware_poplar_mmc_dma.patch
  * arm-trusted-firmware_zynqmp_ipi.patch
* Wed Sep  4 2019 Andreas Färber <afaerber@suse.de>
- Add zynqmp
  * arm-trusted-firmware_zynqmp_ipi.patch
* Thu Aug  1 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add initial bits for a80x0_mcbin support for MacchiatoBin
* Sun Jun 16 2019 Andreas Färber <afaerber@suse.de>
- rpi3: By now building okay with OP-TEE
- rpi3: Replace dependency on deprecated bootstrap code with U-Boot
- rpi3: Change installation location (adopted from u-boot-rpi3)
- poplar: Fix eMMC DMA FIFO breaking U-Boot eMMC access
  (https://review.trustedfirmware.org/c/TF-A/trusted-firmware-a/+/1230)
  arm-trusted-firmware_poplar_mmc_dma.patch
- poplar: Build for both 2 GiB and 1 GiB boards (b96o#834)
* Sat Jun  8 2019 Andreas Färber <afaerber@suse.de>
- Add imxmq and imxmm
* Sat Jun  8 2019 Andreas Färber <afaerber@suse.de>
- Fix build date by escaping %%S (which expanded to %%SOURCE).
- hikey960: Avoid a race condition (boo#1134788)
  arm-trusted-firmware_hikey960_race.patch
* Tue Apr  9 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to v2.1:
  * Add ARMv8.3 pointer authentication in the normal and secure worlds
  * Cortex-Axx workarounds for erratums
  * New platforms
  * Full changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/about/docs/change-log.rst#version-2-1
- Remove outdated patch:
  * hikey960.diff
* Thu Mar 28 2019 Andreas Färber <afaerber@suse.de>
- rpi3: Package armstub8.bin, fip.bin, bl1.bin, bl2.bin
* Sun Nov 11 2018 afaerber@suse.de
- pre_checkin.sh: Fix package names for sun50i_{a64,h6}
* Sun Nov  4 2018 afaerber@suse.de
- Add imx8qm, imx8qx, sun50i_a64, sun50i_h6
* Sun Nov  4 2018 afaerber@suse.de
- Update to v2.0
  * Drop upstream patches
  arm-trusted-firmware_cve-2018-3639_smccc_rename.patch
  arm-trusted-firmware_cve-2018-3639_smccc_return.patch
  arm-trusted-firmware_cve-2018-3639_rename.patch
  arm-trusted-firmware_cve-2018-3639_static.patch
  arm-trusted-firmware_cve-2018-3639_static_aarch32.patch
  arm-trusted-firmware_cve-2018-3639_dynamic.patch
  * fip_create wrapper is no longer built (use fiptool instead)
  * Set BL33 for qemu
* Sun Jun  3 2018 afaerber@suse.de
- Conditionally enable OP-TEE as BL32
* Sun Jun  3 2018 afaerber@suse.de
- Add rpi3
* Sun Jun  3 2018 afaerber@suse.de
- Set BUILD_MESSAGE_TIMESTAMP for reproducible builds
- Simplify tegra packaging, reusing %%target_soc
* Fri Jun  1 2018 afaerber@suse.de
- Address CVE-2018-3639 (bsc#1085308)
  arm-trusted-firmware_cve-2018-3639_smccc_rename.patch
  arm-trusted-firmware_cve-2018-3639_smccc_return.patch
  arm-trusted-firmware_cve-2018-3639_rename.patch
  arm-trusted-firmware_cve-2018-3639_static.patch
  arm-trusted-firmware_cve-2018-3639_static_aarch32.patch
  arm-trusted-firmware_cve-2018-3639_dynamic.patch
* Thu May 31 2018 afaerber@suse.de
- hikey960.diff: Fix assertion on HiKey 960 (b9o#739)
* Thu May 31 2018 afaerber@suse.de
- Package bl2 for hikey and hikey960
* Mon May 21 2018 afaerber@suse.de
- Add tegra186
* Mon May 21 2018 afaerber@suse.de
- Package poplar_layout.h header for l-loader in devel package
* Sun May 20 2018 afaerber@suse.de
- Build recovery version of poplar, too
* Sun May 20 2018 afaerber@suse.de
- Adopt %%license
- Add poplar
- Prepare tegra186
* Sun May 20 2018 afaerber@suse.de
- Update to v1.5
  * Dropped upstream patches:
  arm-trusted-firmware_pie_1.patch
  arm-trusted-firmware_pie_2.patch
  arm-trusted-firmware_fiptool_pad.patch
  arm-trusted-firmware_fiptool_pad_useafterfree.patch
  arm-trusted-firmware_fiptool_pad_hikey.patch
  arm-trusted-firmware_fiptool_pad_hikey960.patch
  arm-trusted-firmware_cve-2017-5715_a57_a72.patch
  arm-trusted-firmware_cve-2017-5715_a73_a75.patch
  arm-trusted-firmware_cve-2017-5715_pfr0.patch
  arm-trusted-firmware_cve-2017-5715_errata_format.patch
  arm-trusted-firmware_cve-2017-5715_errata_output.patch
  arm-trusted-firmware_cve-2017-5715_platforms.patch
  arm-trusted-firmware_cve-2017-5715_bpiall.patch
  arm-trusted-firmware_cve-2017-5715_smccc.patch
  arm-trusted-firmware_cve-2017-5715_psci.patch
  arm-trusted-firmware_cve-2017-5715_runtime_exceptions.patch
  arm-trusted-firmware_cve-2017-5715_smccc_v1.1.patch
* Sat Feb 10 2018 afaerber@suse.de
- Apply fiptool patches to tools package, too (b9o#633)
- Prepare for detecting PIE support (gh#ARM-software/tf-issues#519)
  arm-trusted-firmware_pie_1.patch
  arm-trusted-firmware_pie_2.patch
* Sat Feb 10 2018 afaerber@suse.de
- Implement SMCCC v1.1 (bsc#1074741)
  arm-trusted-firmware_cve-2017-5715_platforms.patch
  arm-trusted-firmware_cve-2017-5715_bpiall.patch
  arm-trusted-firmware_cve-2017-5715_smccc.patch
  arm-trusted-firmware_cve-2017-5715_psci.patch
  arm-trusted-firmware_cve-2017-5715_runtime_exceptions.patch
  arm-trusted-firmware_cve-2017-5715_smccc_v1.1.patch
* Sat Jan 27 2018 afaerber@suse.de
- Pad HiKey FIP to avoid hanging fastboot transfer (b9o#633)
  arm-trusted-firmware_fiptool_pad.patch
  arm-trusted-firmware_fiptool_pad_useafterfree.patch
  arm-trusted-firmware_fiptool_pad_hikey.patch
  arm-trusted-firmware_fiptool_pad_hikey960.patch
* Sat Jan 27 2018 afaerber@suse.de
- Add CVE-2017-5715 output (bsc#1074741)
  arm-trusted-firmware_cve-2017-5715_errata_format.patch
  arm-trusted-firmware_cve-2017-5715_errata_output.patch
* Mon Jan 22 2018 afaerber@suse.de
- Use debug builds
* Fri Jan 12 2018 afaerber@suse.de
- rk3399: Don't require cross binutils (let cross gcc choose which)
* Fri Jan 12 2018 afaerber@suse.de
- hikey960: Build fip and require EDK2 for SCP_BL2 and BL33
- Refresh CVE-2017-5715 patches (bsc#1074741)
  Drop arm-trusted-firmware_cve-2017-5715_ic_iallu.patch
  Add arm-trusted-firmware_cve-2017-5715_pfr0.patch
- Suppress debuginfo for firmware
* Sun Jan  7 2018 afaerber@suse.de
- Make noarch so that it can be exported
* Sun Jan  7 2018 afaerber@suse.de
- hikey: Build fip and require EDK2 for SCP_BL2
- Add tegra210
* Sun Jan  7 2018 afaerber@suse.de
- Add hikey960
* Sun Jan  7 2018 afaerber@suse.de
- Add hikey
- Clean up pre_checkin.sh
- Don't package bl31.bin for Rockchip, we need bl31.elf only
* Fri Jan  5 2018 afaerber@suse.de
- Require arm-none gcc for RK3399
* Fri Jan  5 2018 afaerber@suse.de
- Address CVE-2017-5715 (bsc#1074741)
  arm-trusted-firmware_cve-2017-5715_a57_a72.patch
  arm-trusted-firmware_cve-2017-5715_a73_a75.patch
  arm-trusted-firmware_cve-2017-5715_ic_iallu.patch
* Wed Jan  3 2018 matwey.kornilov@gmail.com
- Return lost doc files
* Tue Jan  2 2018 matwey.kornilov@gmail.com
- Package bl31.elf
* Tue Jan  2 2018 matwey.kornilov@gmail.com
- acknowledgements.md renamed to acknowledgements.rst
* Thu Dec 28 2017 matwey.kornilov@gmail.com
- Version 1.4
* Mon Dec 26 2016 afaerber@suse.de
- Update to v1.3 final
* Sat Oct  8 2016 afaerber@suse.de
- Initial
